#
# spec file for package python-pyvmomi
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2014 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python312 1

%{?sle15_python_module_pythons}
Name:           python-pyvmomi
Version:        7.0.3
Release:        3.1
Summary:        VMware vSphere Python SDK
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/vmware/pyvmomi
Source:         https://github.com/vmware/pyvmomi/archive/v%{version}.tar.gz#/pyvmomi-%{version}.tar.gz
BuildRequires:  %{python_module fixtures >= 1.3.0}
BuildRequires:  %{python_module requests >= 2.3.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six >= 1.7.3}
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module testtools >= 0.9.34}
BuildRequires:  %{python_module tox}
BuildRequires:  %{python_module vcrpy}
# /SECTION
Requires:       python-requests >= 2.3.0
Requires:       python-six >= 1.7.3
Recommends:     python-lxml
Recommends:     python-pyOpenSSL
BuildArch:      noarch
%python_subpackages

%description
pyVmomi is the Python SDK for the VMware vSphere API that allows you to manage
ESX, ESXi, and vCenter.

%prep
%setup -q -n pyvmomi-%{version}%{?version_suffix}
dos2unix README.rst LICENSE.txt NOTICE.txt

# https://github.com/vmware/pyvmomi/pull/750
# Unpin vcrpy; the fix was released
sed -i 's/vcrpy<2/vcrpy/' test-requirements.txt

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pyunittest discover -v

%files %{python_files}
%license LICENSE.txt
%doc NOTICE.txt README.rst
%{python_sitelib}/pyVim
%{python_sitelib}/pyVmomi
%{python_sitelib}/pyvmomi-%{version}*-py*.egg-info

%changelog
* Mon Apr  8 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- add sle15 macro; disable python3.12 builds
* Thu Apr 14 2022 pgajdos@suse.com
- python-mock is not required for build
* Mon Oct 25 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 7.0.3
  * Added new bindings to support vSphere 7.0U3. Includes updates
    to VIM, PBM, EAM and SMS namespaces.
  * New features of vSphere 7.0U3 based on REST APIs are available
    via the vSphere Automation SDK for Python.
  * Outdated samples are removed. Community samples project:
    https://github.com/vmware/pyvmomi-community-samples
  * Bindings files are renamed to _typeinfo_{namespace}.py
  * "stable" version alias is removed
  * "public" version alias is renamed to "LTS"
* Fri May 28 2021 pgajdos@suse.com
- %%check: use %%pyunittest rpm macro
* Fri Apr  9 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 7.0.2
  * Added new bindings to support vSphere 7.0U2. Includes updates
    to VIM, PBM, EAM and SMS namespaces. For details, refer
    “What’s New in vSphere API 7.0U2?” section in the API
    reference guide: https://code.vmware.com/apis/1131/vsphere
* Sat Oct 31 2020 Martin Hauke <mardnh@gmx.de>
- update to version 7.0.1
  * Added new bindings to support vSphere 7.0U1. Includes updates
    to VIM, PBM, and EAM namespaces. For details, refer “What’s
    New in vSphere API 7.0U1?” section in the API reference guide:
    https://code.vmware.com/apis/1067/vsphere
  * New features of vSphere 7.0U1 based on REST APIs are available
    via the vSphere Automation SDK for Python:
    https://github.com/vmware/vsphere-automation-sdk-python
- Switch to github source url
* Tue Apr 14 2020 Martin Hauke <mardnh@gmx.de>
- update to version 7.0
  * Added new bindings to support vSphere 7.0. For details, refer
    "What’s New in vSphere API 7.0?" section in the API reference
    guide: https://code.vmware.com/apis/968/vsphere
  * New features of vSphere 7.0 based on REST APIs are available
    via the vSphere Automation SDK for Python:
    https://github.com/vmware/vsphere-automation-sdk-python
* Sun Sep 15 2019 John Vandenberg <jayvdb@gmail.com>
- Add runtime recommends for pyOpenSSL and lxml, needed for SSO support
- Update to v6.7.3
  * Publish new bindings to support vSphere 6.7 Update 3 Release
  * Add sso.py to support get bearer/hok token from sso server
  * pydoc support Fix
  * httpProxy Support Fix
  * Changes to VmomiSupport to handle API versions
- Convert line endings on README.rst
- Drop python-pyvmomi-fix-incompatibility-with-vcrpy2.patch as the
  vcrpy fix has been released
* Sat Dec 29 2018 mardnh@gmx.de
- Update to version 6.7.1.2018.12
  * Support JSON encoding for pyVmomi objects
  * Fix vcrpy hardening in test-requirements. Support versions < 2.0
  * Delete deprecated Docs folder
- Add patch:
  * python-pyvmomi-fix-incompatibility-with-vcrpy2.patch
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed Nov 21 2018 Santiago Zarate <santiago.zarate@suse.com>
  _ Update to version 6.7.1
  * Publish new bindings to support vSphere 6.7 Update 1 Release
  * Newer features are available via the new vSphere Automation SDK for Python
* Wed Apr 18 2018 mardnh@gmx.de
- Update to version 6.7
  * Publish new bindings to support vSphere 6.7
- Change URL to download sources from github
- Remove hotfix macro
- Enable tests
* Sat Mar  3 2018 arun@gmx.de
- specfile:
  * update copyright year
  * don't use python_module for Requires
* Wed Nov 29 2017 boris@steki.net
- updated to release v6.5.0.2017.5-1
  + Fix SoapAdapter serializer to support serializing unicode chars
  + Remove custom getattr in _HTTPSConnection
  + Add user-agent header when connecting to vsphere
- moved to single spec logic to build py2 and py3 package
* Sun Jan 15 2017 hpj@urpla.net
- fix build: add python-fixtures to build dependencies
* Thu Jan 12 2017 mardnh@gmx.de
- Update to version 6.5
  * Spec bump to support vSphere 6.5.
  * Include EAM bindings to support vSphere EAM service.
  * Fixed server thumbprint verification.
  * Fixed sslcontext creation in sample code.
* Sun Sep 18 2016 mardnh@gmx.de
- Update to version 6.0.0.2016.4
  * Python3 related bug fixes.
  * Include task.py utility class.
- Changes from version 6.0.0
  * Spec bump to support vSphere 6.0 server objects and types
    vSphere 6.0 U1 spec is used
  * New ssl context parameter in Connect.py and SoapAdapter.py to
    support passing various ssl options while connecting to vSphere.
  * Drop python 2.6 support.
  * Critical bug fixes.
- Remove patch: pyvmomi-git20141104-new.diff (fixed upstream)
- Fix Source-Url
* Wed May 13 2015 mc@suse.com
- add requires for python-six and python-requests
* Tue Nov  4 2014 hpj@urpla.net
- version 5.5.0.2014.1.1: initial build
- apply asorted fixes from todays git tree
